summaryrefslogtreecommitdiffstats
path: root/systemsettings/kcmultiwidget.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit79e6120f212414f059a40661108472987714d233 (patch)
tree9fa18a192565fea0e5f75214294853d954180540 /systemsettings/kcmultiwidget.h
parent07915c3e5524895d3745ba0815529b7eaa7e48bc (diff)
downloadtde-systemsettings-79e6120f212414f059a40661108472987714d233.tar.gz
tde-systemsettings-79e6120f212414f059a40661108472987714d233.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kde-systemsettings@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'systemsettings/kcmultiwidget.h')
-rw-r--r--systemsettings/kcmultiwidget.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/systemsettings/kcmultiwidget.h b/systemsettings/kcmultiwidget.h
index 181ba4e..ac68c78 100644
--- a/systemsettings/kcmultiwidget.h
+++ b/systemsettings/kcmultiwidget.h
@@ -46,24 +46,24 @@ public:
/**
* Constructs a new KCMultiWidget
*
* @param tqparent The tqparent widget
* @param name The widget name
* @param modal If you pass true here, the dialog will be modal
**/
- KCMultiWidget( TQWidget *tqparent=0, const char *name=0, bool modal=false );
+ KCMultiWidget( TQWidget *parent=0, const char *name=0, bool modal=false );
/**
* Construct a personalized KCMultiWidget.
*
* @param dialogFace You can use TreeList, Tabbed, Plain, Swallow or
* IconList.
- * @param tqparent Parent of the dialog.
+ * @param parent Parent of the dialog.
* @param name Dialog name (for internal use only).
* @param modal Controls dialog modality. If @p false, the rest of the
* program interface (example: other dialogs) is accessible while
* the dialog is open.
*/
- KCMultiWidget( int dialogFace, TQWidget * tqparent = 0,
+ KCMultiWidget( int dialogFace, TQWidget * parent = 0,
const char * name = 0, bool modal = false );
@@ -46,24 +46,24 @@ public:
* Constructs a new KCMultiWidget
*
- * @param tqparent The tqparent widget
+ * @param parent The parent widget
* @param name The widget name
* @param modal If you pass true here, the dialog will be modal